<a id="mypy-boto3-schemas"></a>

# mypy-boto3-schemas

[![PyPI - mypy-boto3-schemas](https://img.shields.io/pypi/v/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-schemas?color=blue)](https://pypistats.org/packages/mypy-boto3-schemas)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Schemas 1.17.101](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/schemas.html#Schemas)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.20.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-schemas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_schemas/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-schemas](#mypy-boto3-schemas)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Schemas` service.

```bash
python -m pip install boto3-stubs[schemas]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`
- Run `mypy` as usual

Type checking should work for `Schemas` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Schemas` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`SchemasClient` provides annotations for `boto3.client("schemas")`.

```python
import boto3

from mypy_boto3_schemas import SchemasClient

client: SchemasClient = boto3.client("schemas")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SchemasClient = session.client("schemas")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_schemas.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.paginator import (
    ListDiscoverersPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
    SearchSchemasPaginator,
)

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_discoverers_paginator: ListDiscoverersPaginator = client.get_paginator("list_discoverers")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
search_schemas_paginator: SearchSchemasPaginator = client.get_paginator("search_schemas")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_schemas.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.waiter import (
    CodeBindingExistsWaiter,
)

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
code_binding_exists_waiter: CodeBindingExistsWaiter = client.get_waiter("code_binding_exists")
```

<a id="literals"></a>

### Literals

`mypy_boto3_schemas.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_schemas.literals import (
    CodeBindingExistsWaiterName,
    CodeGenerationStatusType,
    DiscovererStateType,
    ListDiscoverersPaginatorName,
    ListRegistriesPaginatorName,
    ListSchemaVersionsPaginatorName,
    ListSchemasPaginatorName,
    SearchSchemasPaginatorName,
    TypeType,
)

def check_value(value: CodeBindingExistsWaiterName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_schemas.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_schemas.type_defs import (
    CreateDiscovererRequestTypeDef,
    CreateDiscovererResponseResponseTypeDef,
    CreateRegistryRequestTypeDef,
    CreateRegistryResponseResponseTypeDef,
    CreateSchemaRequestTypeDef,
    CreateSchemaResponseResponseTypeDef,
    DeleteDiscovererRequestTypeDef,
    DeleteRegistryRequestTypeDef,
    DeleteResourcePolicyRequestTypeDef,
    DeleteSchemaRequestTypeDef,
    DeleteSchemaVersionRequestTypeDef,
    DescribeCodeBindingRequestTypeDef,
    DescribeCodeBindingResponseResponseTypeDef,
    DescribeDiscovererRequestTypeDef,
    DescribeDiscovererResponseResponseTypeDef,
    DescribeRegistryRequestTypeDef,
    DescribeRegistryResponseResponseTypeDef,
    DescribeSchemaRequestTypeDef,
    DescribeSchemaResponseResponseTypeDef,
    DiscovererSummaryTypeDef,
    ExportSchemaRequestTypeDef,
    ExportSchemaResponseResponseTypeDef,
    GetCodeBindingSourceRequestTypeDef,
    GetCodeBindingSourceResponseResponseTypeDef,
    GetDiscoveredSchemaRequestTypeDef,
    GetDiscoveredSchemaResponseResponseTypeDef,
    GetResourcePolicyRequestTypeDef,
    GetResourcePolicyResponseResponseTypeDef,
    ListDiscoverersRequestTypeDef,
    ListDiscoverersResponseResponseTypeDef,
    ListRegistriesRequestTypeDef,
    ListRegistriesResponseResponseTypeDef,
    ListSchemaVersionsRequestTypeDef,
    ListSchemaVersionsResponseResponseTypeDef,
    ListSchemasRequestTypeDef,
    ListSchemasResponseResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseResponseTypeDef,
    PaginatorConfigTypeDef,
    PutCodeBindingRequestTypeDef,
    PutCodeBindingResponseResponseTypeDef,
    PutResourcePolicyRequestTypeDef,
    PutResourcePolicyResponseResponseTypeDef,
    RegistrySummaryTypeDef,
    ResponseMetadataTypeDef,
    SchemaSummaryTypeDef,
    SchemaVersionSummaryTypeDef,
    SearchSchemaSummaryTypeDef,
    SearchSchemaVersionSummaryTypeDef,
    SearchSchemasRequestTypeDef,
    SearchSchemasResponseResponseTypeDef,
    StartDiscovererRequestTypeDef,
    StartDiscovererResponseResponseTypeDef,
    StopDiscovererRequestTypeDef,
    StopDiscovererResponseResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateDiscovererRequestTypeDef,
    UpdateDiscovererResponseResponseTypeDef,
    UpdateRegistryRequestTypeDef,
    UpdateRegistryResponseResponseTypeDef,
    UpdateSchemaRequestTypeDef,
    UpdateSchemaResponseResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> CreateDiscovererRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-schemas` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-schemas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_schemas/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
